@@ -17,7 +17,7 @@ use Rose::Object::MakeMethods::Generic (
     boolean                 => [ 'tt' => { default => 1 }, ]
 );
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 NAME
 
@@ -283,7 +283,7 @@ sub make_catalyst {
     }
 
     # we need 1 dir, possibly 2
-    my $rdgc_tt_dir = dir( $tt_dir, 'crud' );   # used to be 'rdgc'
+    my $rdgc_tt_dir = dir( $tt_dir, 'crud' );      # used to be 'rdgc'
     my $base_tt_dir = dir( $tt_dir, $base_url );
     $rdgc_tt_dir->mkpath(1);
     $base_tt_dir->mkpath(1);
@@ -323,6 +323,8 @@ sub make_catalyst {
     $js_dir->mkpath(1);
     my $css_dir = dir( $tt_dir, 'static', 'css' );
     $css_dir->mkpath(1);
+    my $css_crud_dir = dir( $css_dir, 'crud' );
+    $css_crud_dir->mkpath(1);
 
     copy( file( $cx_crud_yui_tt_path, 'static', 'js', 'crud.js' ),
         file( $js_dir, 'crud.js' ) )
@@ -334,6 +336,14 @@ sub make_catalyst {
         file( $css_dir, 'crud.css' ) )
         or warn "ERROR: failed to copy crud.css to local static/css\n";
 
+    # all the css files
+    my $css_base_dir = dir( $cx_crud_yui_tt_path, 'static', 'css', 'crud' );
+    while ( my $css_file = $css_base_dir->next ) {
+        next unless -f $css_file;
+        copy( $css_file, file( $css_crud_dir, $css_file->basename ) )
+            or warn "ERROR: failed to copy $css_file to $css_crud_dir\n";
+    }
+
     return $garden;
 }
 
@@ -445,25 +455,11 @@ use strict;
 use warnings;
 use base qw( Catalyst::Controller );
 
-sub auto : Private {
-    my (\$self, \$c) = \@_;
-    \$c->stash->{current_view} = 'RDGC';
-    1;
-}
-
 sub default : Path {
     my (\$self, \$c) = \@_;
     \$c->stash->{template} = '$base_path/default.tt';
 }
 
-sub end : ActionClass('RenderView') {
-    my ( \$self, \$c ) = \@_;
-    if ( \$c->req->param('as_xls') ) {
-        \$c->stash->{current_view} = 'Excel';
-        \$c->stash->{template}     = 'rdgc/list.xls.tt';
-    }
-}
-
 1;
 
 EOF
@@ -520,6 +516,15 @@ use strict;
 use warnings;
 use base qw( Rose::DBx::Garden::Catalyst::Controller );
 
+__PACKAGE__->config(
+    default_view    => 'RDGC',
+    fmt_to_view_map => {
+        html => "RDGC",
+        json => "RDGC",
+        xls  => "Excel"
+    },
+);
+
 1;
 
 EOF
